LimitedWrapWidget class

Custom Wrap widget with limited number of rows and optional widget for overflow display

Inheritance

Constructors

LimitedWrapWidget({Key? key, required OverflowBuilderStyle? overflowBuilderStyle, required List<Widget> children, required double spacing, required double runSpacing, int? maxLines})
const
LimitedWrapWidget.builder({Key? key, OnWidgetsLayouted? overflowWidgetBuilder, required List<Widget> children, required double spacing, required double runSpacing, int? maxLines})
const

Properties

children List<Widget>
Children widgets
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines int?
Maximum number of rows
final
overflowBuilderStyle OverflowBuilderStyle?
Style for overflow widget
final
overflowWidgetBuilder OnWidgetsLayouted?
Builder function for overflow widget
final
runSpacing double
Spacing between rows
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
Spacing between elements in a row
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LimitedWrapWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited